pub fn correlation_matrix(series: &[&[ReturnPoint]]) -> Vec<Vec<f64>>Expand description
Pairwise Pearson correlation matrix on return series.
Returns an NxN matrix where entry [i][j] is the correlation between series i and series j.
pub fn correlation_matrix(series: &[&[ReturnPoint]]) -> Vec<Vec<f64>>Pairwise Pearson correlation matrix on return series.
Returns an NxN matrix where entry [i][j] is the correlation between series i and series j.